@@ -26,18 +26,21 @@ def timer(func, label, *args):
     starttime = time.time()
     for x in range(iterations):
         func(*args)
-        if time.time()-starttime > 10:
-            print("%s: breaking at %s iterations, %.6f per iteration" % (
-                label, x+1, (time.time()-starttime)/(x+1.0)))
+        if time.time() - starttime > 10:
+            print(
+                "%s: breaking at %s iterations, %.6f per iteration"
+                % (label, x + 1, (time.time() - starttime) / (x + 1.0))
+            )
             break
-    if x == iterations-1:
+    if x == iterations - 1:
         endtime = time.time()
-        print("%s: %.4f s  %.6f per iteration" % (
-            label, endtime-starttime, (endtime-starttime)/(x+1.0)))
+        print(
+            "%s: %.4f s  %.6f per iteration"
+            % (label, endtime - starttime, (endtime - starttime) / (x + 1.0))
+        )
 
 
 class BenchCffiAccess(PillowTestCase):
-
     def test_direct(self):
         im = hopper()
         im.load()
@@ -48,11 +51,11 @@ class BenchCffiAccess(PillowTestCase):
         self.assertEqual(caccess[(0, 0)], access[(0, 0)])
 
         print("Size: %sx%s" % im.size)
-        timer(iterate_get, 'PyAccess - get', im.size, access)
-        timer(iterate_set, 'PyAccess - set', im.size, access)
-        timer(iterate_get, 'C-api - get', im.size, caccess)
-        timer(iterate_set, 'C-api - set', im.size, caccess)
+        timer(iterate_get, "PyAccess - get", im.size, access)
+        timer(iterate_set, "PyAccess - set", im.size, access)
+        timer(iterate_get, "C-api - get", im.size, caccess)
+        timer(iterate_set, "C-api - set", im.size, caccess)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
