@@ -12,5 +12,5 @@ class TestFliOverflow(PillowTestCase):
         im.load()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
