@@ -4,12 +4,10 @@ from PIL import Image, McIdasImagePlugin
 
 
 class TestFileMcIdas(PillowTestCase):
-
     def test_invalid_file(self):
         invalid_file = "Tests/images/flower.jpg"
 
-        self.assertRaises(SyntaxError,
-                          McIdasImagePlugin.McIdasImageFile, invalid_file)
+        self.assertRaises(SyntaxError, McIdasImagePlugin.McIdasImageFile, invalid_file)
 
     def test_valid_file(self):
         # Arrange
