@@ -4,20 +4,20 @@ from PIL import Image
 
 try:
     from PIL import _webp
+
     HAVE_WEBP = True
 except ImportError:
     HAVE_WEBP = False
 
 
 class TestFileWebpMetadata(PillowTestCase):
-
     def setUp(self):
         if not HAVE_WEBP:
-            self.skipTest('WebP support not installed')
+            self.skipTest("WebP support not installed")
             return
 
         if not _webp.HAVE_WEBPMUX:
-            self.skipTest('WebPMux support not installed')
+            self.skipTest("WebPMux support not installed")
 
     def test_read_exif_metadata(self):
 
@@ -33,8 +33,8 @@ class TestFileWebpMetadata(PillowTestCase):
         # camera make
         self.assertEqual(exif[271], "Canon")
 
-        jpeg_image = Image.open('Tests/images/flower.jpg')
-        expected_exif = jpeg_image.info['exif']
+        jpeg_image = Image.open("Tests/images/flower.jpg")
+        expected_exif = jpeg_image.info["exif"]
 
         self.assertEqual(exif_data, expected_exif)
 
@@ -43,7 +43,7 @@ class TestFileWebpMetadata(PillowTestCase):
 
         file_path = "Tests/images/flower.jpg"
         image = Image.open(file_path)
-        expected_exif = image.info['exif']
+        expected_exif = image.info["exif"]
 
         test_buffer = BytesIO()
 
@@ -52,11 +52,10 @@ class TestFileWebpMetadata(PillowTestCase):
         test_buffer.seek(0)
         webp_image = Image.open(test_buffer)
 
-        webp_exif = webp_image.info.get('exif', None)
+        webp_exif = webp_image.info.get("exif", None)
         self.assertTrue(webp_exif)
         if webp_exif:
-            self.assertEqual(
-                webp_exif, expected_exif, "WebP EXIF didn't match")
+            self.assertEqual(webp_exif, expected_exif, "WebP EXIF didn't match")
 
     def test_read_icc_profile(self):
 
@@ -66,10 +65,10 @@ class TestFileWebpMetadata(PillowTestCase):
         self.assertEqual(image.format, "WEBP")
         self.assertTrue(image.info.get("icc_profile", None))
 
-        icc = image.info['icc_profile']
+        icc = image.info["icc_profile"]
 
-        jpeg_image = Image.open('Tests/images/flower2.jpg')
-        expected_icc = jpeg_image.info['icc_profile']
+        jpeg_image = Image.open("Tests/images/flower2.jpg")
+        expected_icc = jpeg_image.info["icc_profile"]
 
         self.assertEqual(icc, expected_icc)
 
@@ -78,7 +77,7 @@ class TestFileWebpMetadata(PillowTestCase):
 
         file_path = "Tests/images/flower2.jpg"
         image = Image.open(file_path)
-        expected_icc_profile = image.info['icc_profile']
+        expected_icc_profile = image.info["icc_profile"]
 
         test_buffer = BytesIO()
 
@@ -87,20 +86,20 @@ class TestFileWebpMetadata(PillowTestCase):
         test_buffer.seek(0)
         webp_image = Image.open(test_buffer)
 
-        webp_icc_profile = webp_image.info.get('icc_profile', None)
+        webp_icc_profile = webp_image.info.get("icc_profile", None)
 
         self.assertTrue(webp_icc_profile)
         if webp_icc_profile:
             self.assertEqual(
-                webp_icc_profile, expected_icc_profile,
-                "Webp ICC didn't match")
+                webp_icc_profile, expected_icc_profile, "Webp ICC didn't match"
+            )
 
     def test_read_no_exif(self):
         from io import BytesIO
 
         file_path = "Tests/images/flower.jpg"
         image = Image.open(file_path)
-        self.assertIn('exif', image.info)
+        self.assertIn("exif", image.info)
 
         test_buffer = BytesIO()
 
@@ -113,23 +112,28 @@ class TestFileWebpMetadata(PillowTestCase):
 
     def test_write_animated_metadata(self):
         if not _webp.HAVE_WEBPANIM:
-            self.skipTest('WebP animation support not available')
+            self.skipTest("WebP animation support not available")
 
-        iccp_data = '<iccp_data>'.encode('utf-8')
-        exif_data = '<exif_data>'.encode('utf-8')
-        xmp_data = '<xmp_data>'.encode('utf-8')
+        iccp_data = "<iccp_data>".encode("utf-8")
+        exif_data = "<exif_data>".encode("utf-8")
+        xmp_data = "<xmp_data>".encode("utf-8")
 
         temp_file = self.tempfile("temp.webp")
-        frame1 = Image.open('Tests/images/anim_frame1.webp')
-        frame2 = Image.open('Tests/images/anim_frame2.webp')
-        frame1.save(temp_file, save_all=True,
-                    append_images=[frame2, frame1, frame2],
-                    icc_profile=iccp_data, exif=exif_data, xmp=xmp_data)
+        frame1 = Image.open("Tests/images/anim_frame1.webp")
+        frame2 = Image.open("Tests/images/anim_frame2.webp")
+        frame1.save(
+            temp_file,
+            save_all=True,
+            append_images=[frame2, frame1, frame2],
+            icc_profile=iccp_data,
+            exif=exif_data,
+            xmp=xmp_data,
+        )
 
         image = Image.open(temp_file)
-        self.assertIn('icc_profile', image.info)
-        self.assertIn('exif', image.info)
-        self.assertIn('xmp', image.info)
-        self.assertEqual(iccp_data, image.info.get('icc_profile', None))
-        self.assertEqual(exif_data, image.info.get('exif', None))
-        self.assertEqual(xmp_data, image.info.get('xmp', None))
+        self.assertIn("icc_profile", image.info)
+        self.assertIn("exif", image.info)
+        self.assertIn("xmp", image.info)
+        self.assertEqual(iccp_data, image.info.get("icc_profile", None))
+        self.assertEqual(exif_data, image.info.get("exif", None))
+        self.assertEqual(xmp_data, image.info.get("xmp", None))
