@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 
 from PIL import Image, XpmImagePlugin
 
@@ -6,7 +6,6 @@ TEST_FILE = "Tests/images/hopper.xpm"
 
 
 class TestFileXpm(PillowTestCase):
-
     def test_sanity(self):
         im = Image.open(TEST_FILE)
         im.load()
@@ -15,13 +14,12 @@ class TestFileXpm(PillowTestCase):
         self.assertEqual(im.format, "XPM")
 
         # large error due to quantization->44 colors.
-        self.assert_image_similar(im.convert('RGB'), hopper('RGB'), 60)
+        self.assert_image_similar(im.convert("RGB"), hopper("RGB"), 60)
 
     def test_invalid_file(self):
         invalid_file = "Tests/images/flower.jpg"
 
-        self.assertRaises(SyntaxError,
-                          lambda: XpmImagePlugin.XpmImageFile(invalid_file))
+        self.assertRaises(SyntaxError, XpmImagePlugin.XpmImageFile, invalid_file)
 
     def test_load_read(self):
         # Arrange
@@ -33,7 +31,3 @@ class TestFileXpm(PillowTestCase):
 
         # Assert
         self.assertEqual(len(data), 16384)
-
-
-if __name__ == '__main__':
-    unittest.main()
