@@ -4,33 +4,35 @@ from PIL import Image
 
 
 class TestImageSplit(PillowTestCase):
-
     def test_split(self):
         def split(mode):
             layers = hopper(mode).split()
             return [(i.mode, i.size[0], i.size[1]) for i in layers]
-        self.assertEqual(split("1"), [('1', 128, 128)])
-        self.assertEqual(split("L"), [('L', 128, 128)])
-        self.assertEqual(split("I"), [('I', 128, 128)])
-        self.assertEqual(split("F"), [('F', 128, 128)])
-        self.assertEqual(split("P"), [('P', 128, 128)])
+
+        self.assertEqual(split("1"), [("1", 128, 128)])
+        self.assertEqual(split("L"), [("L", 128, 128)])
+        self.assertEqual(split("I"), [("I", 128, 128)])
+        self.assertEqual(split("F"), [("F", 128, 128)])
+        self.assertEqual(split("P"), [("P", 128, 128)])
         self.assertEqual(
-            split("RGB"), [('L', 128, 128), ('L', 128, 128), ('L', 128, 128)])
+            split("RGB"), [("L", 128, 128), ("L", 128, 128), ("L", 128, 128)]
+        )
         self.assertEqual(
             split("RGBA"),
-            [('L', 128, 128), ('L', 128, 128),
-                ('L', 128, 128), ('L', 128, 128)])
+            [("L", 128, 128), ("L", 128, 128), ("L", 128, 128), ("L", 128, 128)],
+        )
         self.assertEqual(
             split("CMYK"),
-            [('L', 128, 128), ('L', 128, 128),
-                ('L', 128, 128), ('L', 128, 128)])
+            [("L", 128, 128), ("L", 128, 128), ("L", 128, 128), ("L", 128, 128)],
+        )
         self.assertEqual(
-            split("YCbCr"),
-            [('L', 128, 128), ('L', 128, 128), ('L', 128, 128)])
+            split("YCbCr"), [("L", 128, 128), ("L", 128, 128), ("L", 128, 128)]
+        )
 
     def test_split_merge(self):
         def split_merge(mode):
             return Image.merge(mode, hopper(mode).split())
+
         self.assert_image_equal(hopper("1"), split_merge("1"))
         self.assert_image_equal(hopper("L"), split_merge("L"))
         self.assert_image_equal(hopper("I"), split_merge("I"))
@@ -44,7 +46,7 @@ class TestImageSplit(PillowTestCase):
     def test_split_open(self):
         codecs = dir(Image.core)
 
-        if 'zip_encoder' in codecs:
+        if "zip_encoder" in codecs:
             test_file = self.tempfile("temp.png")
         else:
             test_file = self.tempfile("temp.pcx")
@@ -53,9 +55,10 @@ class TestImageSplit(PillowTestCase):
             hopper(mode).save(test_file)
             im = Image.open(test_file)
             return len(im.split())
+
         self.assertEqual(split_open("1"), 1)
         self.assertEqual(split_open("L"), 1)
         self.assertEqual(split_open("P"), 1)
         self.assertEqual(split_open("RGB"), 3)
-        if 'zip_encoder' in codecs:
+        if "zip_encoder" in codecs:
             self.assertEqual(split_open("RGBA"), 4)
