@@ -8,6 +8,7 @@ from PIL import EpsImagePlugin
 
 try:
     from PIL import _webp
+
     HAVE_WEBP = True
 except ImportError:
     HAVE_WEBP = False
@@ -21,9 +22,7 @@ SAFEBLOCK = ImageFile.SAFEBLOCK
 
 
 class TestImageFile(PillowTestCase):
-
     def test_parser(self):
-
         def roundtrip(format):
 
             im = hopper("L").resize((1000, 1000))
@@ -44,7 +43,7 @@ class TestImageFile(PillowTestCase):
 
         self.assert_image_equal(*roundtrip("BMP"))
         im1, im2 = roundtrip("GIF")
-        self.assert_image_similar(im1.convert('P'), im2, 1)
+        self.assert_image_similar(im1.convert("P"), im2, 1)
         self.assert_image_equal(*roundtrip("IM"))
         self.assert_image_equal(*roundtrip("MSP"))
         if "zip_encoder" in codecs:
@@ -69,7 +68,7 @@ class TestImageFile(PillowTestCase):
             # md5sum: ba974835ff2d6f3f2fd0053a23521d4a
 
             # EPS comes back in RGB:
-            self.assert_image_similar(im1, im2.convert('L'), 20)
+            self.assert_image_similar(im1, im2.convert("L"), 20)
 
         if "jpeg_encoder" in codecs:
             im1, im2 = roundtrip("JPEG")  # lossy compression
@@ -78,7 +77,7 @@ class TestImageFile(PillowTestCase):
         self.assertRaises(IOError, roundtrip, "PDF")
 
     def test_ico(self):
-        with open('Tests/images/python.ico', 'rb') as f:
+        with open("Tests/images/python.ico", "rb") as f:
             data = f.read()
         with ImageFile.Parser() as p:
             p.feed(data)
@@ -158,14 +157,13 @@ xoff, yoff, xsize, ysize = 10, 20, 100, 100
 
 class MockImageFile(ImageFile.ImageFile):
     def _open(self):
-        self.rawmode = 'RGBA'
-        self.mode = 'RGBA'
+        self.rawmode = "RGBA"
+        self.mode = "RGBA"
         self._size = (200, 200)
-        self.tile = [("MOCK", (xoff, yoff, xoff+xsize, yoff+ysize), 32, None)]
+        self.tile = [("MOCK", (xoff, yoff, xoff + xsize, yoff + ysize), 32, None)]
 
 
 class TestPyDecoder(PillowTestCase):
-
     def get_decoder(self):
         decoder = MockPyDecoder(None)
 
@@ -173,11 +171,11 @@ class TestPyDecoder(PillowTestCase):
             decoder.__init__(mode, *args)
             return decoder
 
-        Image.register_decoder('MOCK', closure)
+        Image.register_decoder("MOCK", closure)
         return decoder
 
     def test_setimage(self):
-        buf = BytesIO(b'\x00'*255)
+        buf = BytesIO(b"\x00" * 255)
 
         im = MockImageFile(buf)
         d = self.get_decoder()
@@ -189,10 +187,10 @@ class TestPyDecoder(PillowTestCase):
         self.assertEqual(d.state.xsize, xsize)
         self.assertEqual(d.state.ysize, ysize)
 
-        self.assertRaises(ValueError, d.set_as_raw, b'\x00')
+        self.assertRaises(ValueError, d.set_as_raw, b"\x00")
 
     def test_extents_none(self):
-        buf = BytesIO(b'\x00'*255)
+        buf = BytesIO(b"\x00" * 255)
 
         im = MockImageFile(buf)
         im.tile = [("MOCK", None, 32, None)]
@@ -206,35 +204,31 @@ class TestPyDecoder(PillowTestCase):
         self.assertEqual(d.state.ysize, 200)
 
     def test_negsize(self):
-        buf = BytesIO(b'\x00'*255)
+        buf = BytesIO(b"\x00" * 255)
 
         im = MockImageFile(buf)
-        im.tile = [("MOCK", (xoff, yoff, -10, yoff+ysize), 32, None)]
+        im.tile = [("MOCK", (xoff, yoff, -10, yoff + ysize), 32, None)]
         self.get_decoder()
 
         self.assertRaises(ValueError, im.load)
 
-        im.tile = [("MOCK", (xoff, yoff, xoff+xsize, -10), 32, None)]
+        im.tile = [("MOCK", (xoff, yoff, xoff + xsize, -10), 32, None)]
         self.assertRaises(ValueError, im.load)
 
     def test_oversize(self):
-        buf = BytesIO(b'\x00'*255)
+        buf = BytesIO(b"\x00" * 255)
 
         im = MockImageFile(buf)
-        im.tile = [
-            ("MOCK", (xoff, yoff, xoff+xsize + 100, yoff+ysize), 32, None)
-        ]
+        im.tile = [("MOCK", (xoff, yoff, xoff + xsize + 100, yoff + ysize), 32, None)]
         self.get_decoder()
 
         self.assertRaises(ValueError, im.load)
 
-        im.tile = [
-            ("MOCK", (xoff, yoff, xoff+xsize, yoff+ysize + 100), 32, None)
-        ]
+        im.tile = [("MOCK", (xoff, yoff, xoff + xsize, yoff + ysize + 100), 32, None)]
         self.assertRaises(ValueError, im.load)
 
     def test_no_format(self):
-        buf = BytesIO(b'\x00'*255)
+        buf = BytesIO(b"\x00" * 255)
 
         im = MockImageFile(buf)
         self.assertIsNone(im.format)
@@ -248,7 +242,7 @@ class TestPyDecoder(PillowTestCase):
         self.assertEqual(exif[40963], 450)
         self.assertEqual(exif[11], "gThumb 3.0.1")
 
-        out = self.tempfile('temp.jpg')
+        out = self.tempfile("temp.jpg")
         exif[258] = 8
         del exif[40960]
         exif[40963] = 455
@@ -268,7 +262,7 @@ class TestPyDecoder(PillowTestCase):
         self.assertEqual(exif[40963], 200)
         self.assertEqual(exif[305], "Adobe Photoshop CC 2017 (Macintosh)")
 
-        out = self.tempfile('temp.jpg')
+        out = self.tempfile("temp.jpg")
         exif[258] = 8
         del exif[34665]
         exif[40963] = 455
@@ -281,14 +275,16 @@ class TestPyDecoder(PillowTestCase):
         self.assertEqual(reloaded_exif[40963], 455)
         self.assertEqual(exif[305], "Pillow test")
 
-    @unittest.skipIf(not HAVE_WEBP or not _webp.HAVE_WEBPANIM,
-                     "WebP support not installed with animation")
+    @unittest.skipIf(
+        not HAVE_WEBP or not _webp.HAVE_WEBPANIM,
+        "WebP support not installed with animation",
+    )
     def test_exif_webp(self):
         im = Image.open("Tests/images/hopper.webp")
         exif = im.getexif()
         self.assertEqual(exif, {})
 
-        out = self.tempfile('temp.webp')
+        out = self.tempfile("temp.webp")
         exif[258] = 8
         exif[40963] = 455
         exif[305] = "Pillow test"
@@ -299,6 +295,7 @@ class TestPyDecoder(PillowTestCase):
             self.assertEqual(reloaded_exif[258], 8)
             self.assertEqual(reloaded_exif[40963], 455)
             self.assertEqual(exif[305], "Pillow test")
+
         im.save(out, exif=exif)
         check_exif()
         im.save(out, exif=exif, save_all=True)
@@ -309,7 +306,7 @@ class TestPyDecoder(PillowTestCase):
         exif = im.getexif()
         self.assertEqual(exif, {274: 1})
 
-        out = self.tempfile('temp.png')
+        out = self.tempfile("temp.png")
         exif[258] = 8
         del exif[274]
         exif[40963] = 455
@@ -318,18 +315,11 @@ class TestPyDecoder(PillowTestCase):
 
         reloaded = Image.open(out)
         reloaded_exif = reloaded.getexif()
-        self.assertEqual(reloaded_exif, {
-            258: 8,
-            40963: 455,
-            305: 'Pillow test',
-        })
+        self.assertEqual(reloaded_exif, {258: 8, 40963: 455, 305: "Pillow test"})
 
     def test_exif_interop(self):
         im = Image.open("Tests/images/flower.jpg")
         exif = im.getexif()
-        self.assertEqual(exif.get_ifd(0xa005), {
-            1: 'R98',
-            2: b'0100',
-            4097: 2272,
-            4098: 1704,
-        })
+        self.assertEqual(
+            exif.get_ifd(0xA005), {1: "R98", 2: b"0100", 4097: 2272, 4098: 1704}
+        )
