@@ -17,13 +17,15 @@ if ImageQt.qt_is_installed:
 
     def skip_if_qt_is_not_installed(_):
         pass
+
+
 else:
+
     def skip_if_qt_is_not_installed(test_case):
-        test_case.skipTest('Qt bindings are not installed')
+        test_case.skipTest("Qt bindings are not installed")
 
 
 class PillowQtTestCase(object):
-
     def setUp(self):
         skip_if_qt_is_not_installed(self)
 
@@ -32,20 +34,19 @@ class PillowQtTestCase(object):
 
 
 class PillowQPixmapTestCase(PillowQtTestCase):
-
     def setUp(self):
         PillowQtTestCase.setUp(self)
         try:
-            if ImageQt.qt_version == '5':
+            if ImageQt.qt_version == "5":
                 from PyQt5.QtGui import QGuiApplication
-            elif ImageQt.qt_version == '4':
+            elif ImageQt.qt_version == "4":
                 from PyQt4.QtGui import QGuiApplication
-            elif ImageQt.qt_version == 'side':
+            elif ImageQt.qt_version == "side":
                 from PySide.QtGui import QGuiApplication
-            elif ImageQt.qt_version == 'side2':
+            elif ImageQt.qt_version == "side2":
                 from PySide2.QtGui import QGuiApplication
         except ImportError:
-            self.skipTest('QGuiApplication not installed')
+            self.skipTest("QGuiApplication not installed")
 
         self.app = QGuiApplication([])
 
@@ -55,29 +56,28 @@ class PillowQPixmapTestCase(PillowQtTestCase):
 
 
 class TestImageQt(PillowQtTestCase, PillowTestCase):
-
     def test_rgb(self):
         # from https://doc.qt.io/archives/qt-4.8/qcolor.html
         # typedef QRgb
         # An ARGB quadruplet on the format #AARRGGBB,
         # equivalent to an unsigned int.
-        if ImageQt.qt_version == '5':
+        if ImageQt.qt_version == "5":
             from PyQt5.QtGui import qRgb
-        elif ImageQt.qt_version == '4':
+        elif ImageQt.qt_version == "4":
             from PyQt4.QtGui import qRgb
-        elif ImageQt.qt_version == 'side':
+        elif ImageQt.qt_version == "side":
             from PySide.QtGui import qRgb
-        elif ImageQt.qt_version == 'side2':
+        elif ImageQt.qt_version == "side2":
             from PySide2.QtGui import qRgb
 
         self.assertEqual(qRgb(0, 0, 0), qRgba(0, 0, 0, 255))
 
         def checkrgb(r, g, b):
             val = ImageQt.rgb(r, g, b)
-            val = val % 2**24  # drop the alpha
+            val = val % 2 ** 24  # drop the alpha
             self.assertEqual(val >> 16, r)
-            self.assertEqual(((val >> 8) % 2**8), g)
-            self.assertEqual(val % 2**8, b)
+            self.assertEqual(((val >> 8) % 2 ** 8), g)
+            self.assertEqual(val % 2 ** 8, b)
 
         checkrgb(0, 0, 0)
         checkrgb(255, 0, 0)
@@ -85,7 +85,7 @@ class TestImageQt(PillowQtTestCase, PillowTestCase):
         checkrgb(0, 0, 255)
 
     def test_image(self):
-        for mode in ('1', 'RGB', 'RGBA', 'L', 'P'):
+        for mode in ("1", "RGB", "RGBA", "L", "P"):
             ImageQt.ImageQt(hopper(mode))
 
     def test_deprecated(self):
