@@ -4,7 +4,6 @@ from PIL import Image
 
 
 class TestLibImage(PillowTestCase):
-
     def test_setmode(self):
 
         im = Image.new("L", (1, 1), 255)
@@ -33,5 +32,5 @@ class TestLibImage(PillowTestCase):
         self.assertRaises(ValueError, im.im.setmode, "RGBABCDE")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
