@@ -1,6 +1,6 @@
 from __future__ import print_function
 
-from helper import PillowTestCase, hopper, unittest
+from .helper import PillowTestCase, hopper, unittest
 from PIL import Image
 
 try:
@@ -15,7 +15,6 @@ TEST_IMAGE_SIZE = (10, 10)
 @unittest.skipIf(numpy is None, "Numpy is not installed")
 class TestNumpy(PillowTestCase):
     def test_numpy_to_image(self):
-
         def to_image(dtype, bands=1, boolean=0):
             if bands == 1:
                 if boolean:
@@ -29,17 +28,16 @@ class TestNumpy(PillowTestCase):
                     print("data mismatch for", dtype)
             else:
                 data = list(range(100))
-                a = numpy.array([[x]*bands for x in data], dtype=dtype)
+                a = numpy.array([[x] * bands for x in data], dtype=dtype)
                 a.shape = TEST_IMAGE_SIZE[0], TEST_IMAGE_SIZE[1], bands
                 i = Image.fromarray(a)
                 if list(i.getchannel(0).getdata()) != list(range(100)):
                     print("data mismatch for", dtype)
-            # print(dtype, list(i.getdata()))
             return i
 
         # Check supported 1-bit integer formats
-        self.assert_image(to_image(numpy.bool, 1, 1), '1', TEST_IMAGE_SIZE)
-        self.assert_image(to_image(numpy.bool8, 1, 1), '1', TEST_IMAGE_SIZE)
+        self.assert_image(to_image(numpy.bool, 1, 1), "1", TEST_IMAGE_SIZE)
+        self.assert_image(to_image(numpy.bool8, 1, 1), "1", TEST_IMAGE_SIZE)
 
         # Check supported 8-bit integer formats
         self.assert_image(to_image(numpy.uint8), "L", TEST_IMAGE_SIZE)
@@ -54,7 +52,7 @@ class TestNumpy(PillowTestCase):
         # self.assert_image(to_image(numpy.int), "I", TEST_IMAGE_SIZE)
 
         # Check 16-bit integer formats
-        if Image._ENDIAN == '<':
+        if Image._ENDIAN == "<":
             self.assert_image(to_image(numpy.uint16), "I;16", TEST_IMAGE_SIZE)
         else:
             self.assert_image(to_image(numpy.uint16), "I;16B", TEST_IMAGE_SIZE)
@@ -97,34 +95,31 @@ class TestNumpy(PillowTestCase):
         np_size = np.shape[1], np.shape[0]
         self.assertEqual(img.size, np_size)
         px = img.load()
-        for x in range(0, img.size[0], int(img.size[0]/10)):
-            for y in range(0, img.size[1], int(img.size[1]/10)):
+        for x in range(0, img.size[0], int(img.size[0] / 10)):
+            for y in range(0, img.size[1], int(img.size[1] / 10)):
                 self.assert_deep_equal(px[x, y], np[y, x])
 
     def test_16bit(self):
-        img = Image.open('Tests/images/16bit.cropped.tif')
+        img = Image.open("Tests/images/16bit.cropped.tif")
         np_img = numpy.array(img)
         self._test_img_equals_nparray(img, np_img)
-        self.assertEqual(np_img.dtype, numpy.dtype('<u2'))
+        self.assertEqual(np_img.dtype, numpy.dtype("<u2"))
 
     def test_1bit(self):
         # Test that 1-bit arrays convert to numpy and back
         # See: https://github.com/python-pillow/Pillow/issues/350
-        arr = numpy.array([[1, 0, 0, 1, 0], [0, 1, 0, 0, 0]], 'u1')
-        img = Image.fromarray(arr * 255).convert('1')
-        self.assertEqual(img.mode, '1')
+        arr = numpy.array([[1, 0, 0, 1, 0], [0, 1, 0, 0, 0]], "u1")
+        img = Image.fromarray(arr * 255).convert("1")
+        self.assertEqual(img.mode, "1")
         arr_back = numpy.array(img)
-        # numpy 1.8 and earlier return this as a boolean. (trusty/precise)
-        if arr_back.dtype == numpy.bool:
-            arr_bool = numpy.array([[1, 0, 0, 1, 0], [0, 1, 0, 0, 0]], 'bool')
-            numpy.testing.assert_array_equal(arr_bool, arr_back)
-        else:
-            numpy.testing.assert_array_equal(arr, arr_back)
+        numpy.testing.assert_array_equal(arr, arr_back)
 
     def test_save_tiff_uint16(self):
         # Tests that we're getting the pixel value in the right byte order.
         pixel_value = 0x1234
-        a = numpy.array([pixel_value] * TEST_IMAGE_SIZE[0] * TEST_IMAGE_SIZE[1], dtype=numpy.uint16)
+        a = numpy.array(
+            [pixel_value] * TEST_IMAGE_SIZE[0] * TEST_IMAGE_SIZE[1], dtype=numpy.uint16
+        )
         a.shape = TEST_IMAGE_SIZE
         img = Image.fromarray(a)
 
@@ -132,7 +127,6 @@ class TestNumpy(PillowTestCase):
         self.assertEqual(img_px[0, 0], pixel_value)
 
     def test_to_array(self):
-
         def _to_array(mode, dtype):
             img = hopper(mode)
 
@@ -142,22 +136,23 @@ class TestNumpy(PillowTestCase):
 
             np_img = numpy.array(img)
             self._test_img_equals_nparray(img, np_img)
-            self.assertEqual(np_img.dtype, numpy.dtype(dtype))
+            self.assertEqual(np_img.dtype, dtype)
 
-        modes = [("L", 'uint8'),
-                 ("I", 'int32'),
-                 ("F", 'float32'),
-                 ("LA", 'uint8'),
-                 ("RGB", 'uint8'),
-                 ("RGBA", 'uint8'),
-                 ("RGBX", 'uint8'),
-                 ("CMYK", 'uint8'),
-                 ("YCbCr", 'uint8'),
-                 ("I;16", '<u2'),
-                 ("I;16B", '>u2'),
-                 ("I;16L", '<u2'),
-                 ("HSV", 'uint8'),
-                 ]
+        modes = [
+            ("L", numpy.uint8),
+            ("I", numpy.int32),
+            ("F", numpy.float32),
+            ("LA", numpy.uint8),
+            ("RGB", numpy.uint8),
+            ("RGBA", numpy.uint8),
+            ("RGBX", numpy.uint8),
+            ("CMYK", numpy.uint8),
+            ("YCbCr", numpy.uint8),
+            ("I;16", "<u2"),
+            ("I;16B", ">u2"),
+            ("I;16L", "<u2"),
+            ("HSV", numpy.uint8),
+        ]
 
         for mode in modes:
             _to_array(*mode)
@@ -165,8 +160,8 @@ class TestNumpy(PillowTestCase):
     def test_point_lut(self):
         # see https://github.com/python-pillow/Pillow/issues/439
 
-        data = list(range(256))*3
-        lut = numpy.array(data, dtype='uint8')
+        data = list(range(256)) * 3
+        lut = numpy.array(data, dtype=numpy.uint8)
 
         im = hopper()
 
@@ -176,12 +171,29 @@ class TestNumpy(PillowTestCase):
         # shouldn't segfault
         # see https://github.com/python-pillow/Pillow/issues/1008
 
-        im = Image.new('F', (150, 100))
+        im = Image.new("F", (150, 100))
         arr = numpy.zeros((15000,), numpy.float32)
         im.putdata(arr)
 
         self.assertEqual(len(im.getdata()), len(arr))
 
+    def test_roundtrip_eye(self):
+        for dtype in (
+            numpy.bool,
+            numpy.bool8,
+            numpy.int8,
+            numpy.int16,
+            numpy.int32,
+            numpy.uint8,
+            numpy.uint16,
+            numpy.uint32,
+            numpy.float,
+            numpy.float32,
+            numpy.float64,
+        ):
+            arr = numpy.eye(10, dtype=dtype)
+            numpy.testing.assert_array_equal(arr, numpy.array(Image.fromarray(arr)))
+
     def test_zero_size(self):
         # Shouldn't cause floating point exception
         # See https://github.com/python-pillow/Pillow/issues/2259
@@ -202,12 +214,9 @@ class TestNumpy(PillowTestCase):
         # https://github.com/python-pillow/Pillow/issues/835
         # Arrange
         from numpy import array
-        test_file = 'Tests/images/hopper.png'
+
+        test_file = "Tests/images/hopper.png"
         im = Image.open(test_file)
 
         # Act/Assert
         self.assert_warning(None, lambda: array(im))
-
-
-if __name__ == '__main__':
-    unittest.main()
