@@ -5,7 +5,7 @@ from __future__ import print_function
 import sys
 import os
 
-from PIL import Image, ImageDraw, ImageFilter, ImageMath
+from PIL import Image
 from PIL import features
 
 try:
@@ -26,6 +26,7 @@ def testimage():
     """
     PIL lets you create in-memory images with various pixel types:
 
+    >>> from PIL import Image, ImageDraw, ImageFilter, ImageMath
     >>> im = Image.new("1", (128, 128)) # monochrome
     >>> _info(im)
     (None, '1', (128, 128))
@@ -89,6 +90,8 @@ def testimage():
     2
     >>> len(im.histogram())
     768
+    >>> '%.7f' % im.entropy()
+    '8.8212866'
     >>> _info(im.point(list(range(256))*3))
     (None, 'RGB', (128, 128))
     >>> _info(im.resize((64, 64)))
@@ -160,12 +163,12 @@ if __name__ == "__main__":
 
     exit_status = 0
 
-    print("-"*68)
+    print("-" * 68)
     print("Pillow", Image.__version__, "TEST SUMMARY ")
-    print("-"*68)
+    print("-" * 68)
     print("Python modules loaded from", os.path.dirname(Image.__file__))
     print("Binary modules loaded from", os.path.dirname(Image.core.__file__))
-    print("-"*68)
+    print("-" * 68)
     for name, feature in [
         ("pil", "PIL CORE"),
         ("tkinter", "TKINTER"),
@@ -179,16 +182,17 @@ if __name__ == "__main__":
         ("jpg_2000", "OPENJPEG (JPEG2000)"),
         ("zlib", "ZLIB (PNG/ZIP)"),
         ("libtiff", "LIBTIFF"),
-        ("raqm", "RAQM (Bidirectional Text)")
+        ("raqm", "RAQM (Bidirectional Text)"),
     ]:
         if features.check(name):
             print("---", feature, "support ok")
         else:
             print("***", feature, "support not installed")
-    print("-"*68)
+    print("-" * 68)
 
     # use doctest to make sure the test program behaves as documented!
     import doctest
+
     print("Running selftest:")
     status = doctest.testmod(sys.modules[__name__])
     if status[0]:
