@@ -147,7 +147,7 @@ void _tiffUnmapProc(thandle_t hdata, tdata_t base, toff_t size) {
     (void) hdata; (void) base; (void) size;
 }
 
-int ImagingLibTiffInit(ImagingCodecState state, int fp, int offset) {
+int ImagingLibTiffInit(ImagingCodecState state, int fp, uint32 offset) {
     TIFFSTATE *clientstate = (TIFFSTATE *)state->context;
 
     TRACE(("initing libtiff\n"));
@@ -194,6 +194,9 @@ int ReadTile(TIFF* tiff, UINT32 col, UINT32 row, UINT32* buffer) {
         }
 
         swap_line = (UINT32*)malloc(swap_line_size);
+        if (swap_line == NULL) {
+            return -1;
+        }
         /*
          * For some reason the TIFFReadRGBATile() function chooses the
          * lower left corner as the origin.  Vertically mirror scanlines.
@@ -275,7 +278,7 @@ int ReadStrip(TIFF* tiff, UINT32 row, UINT32* buffer) {
     return 0;
 }
 
-int ImagingLibTiffDecode(Imaging im, ImagingCodecState state, UINT8* buffer, int bytes) {
+int ImagingLibTiffDecode(Imaging im, ImagingCodecState state, UINT8* buffer, Py_ssize_t bytes) {
     TIFFSTATE *clientstate = (TIFFSTATE *)state->context;
     char *filename = "tempfile.tif";
     char *mode = "r";
@@ -517,15 +520,33 @@ int ImagingLibTiffEncodeInit(ImagingCodecState state, char *filename, int fp) {
 
 }
 
-int ImagingLibTiffMergeFieldInfo(ImagingCodecState state, TIFFDataType field_type, int key){
+int ImagingLibTiffMergeFieldInfo(ImagingCodecState state, TIFFDataType field_type, int key, int is_var_length){
+    // Refer to libtiff docs (http://www.simplesystems.org/libtiff/addingtags.html)
     TIFFSTATE *clientstate = (TIFFSTATE *)state->context;
     char field_name[10];
     uint32 n;
     int status = 0;
 
-    const TIFFFieldInfo info[] = {
-        { key, 0, 1, field_type, FIELD_CUSTOM, 1, 0, field_name }
+    // custom fields added with ImagingLibTiffMergeFieldInfo are only used for
+    // decoding, ignore readcount;
+    int readcount = 0;
+    // we support writing a single value, or a variable number of values
+    int writecount = 1;
+    // whether the first value should encode the number of values.
+    int passcount = 0;
+
+    TIFFFieldInfo info[] = {
+        { key, readcount, writecount, field_type, FIELD_CUSTOM, 1, passcount, field_name }
     };
+
+    if (is_var_length) {
+        info[0].field_writecount = -1;
+    }
+
+    if (is_var_length && field_type != TIFF_ASCII) {
+        info[0].field_passcount = 1;
+    }
+
     n = sizeof(info) / sizeof(info[0]);
 
     // Test for libtiff 4.0 or later, excluding libtiff 3.9.6 and 3.9.7
